# [kollavarsham](http://kollavarsham.org/)

[![Build Status](https://img.shields.io/travis/kollavarsham/kollavarsham-js.svg)](https://travis-ci.org/kollavarsham/kollavarsham-js) [![Dependency Status](https://img.shields.io/david/kollavarsham/kollavarsham-js.svg)](https://david-dm.org/kollavarsham/kollavarsham-js) [![Dev-Dependency Status](https://img.shields.io/david/dev/kollavarsham/kollavarsham-js.svg)](https://david-dm.org/kollavarsham/kollavarsham-js#info=devDependencies&view=table) [![Coverage Status](https://coveralls.io/repos/github/kollavarsham/kollavarsham-js/badge.svg?branch=master)](https://coveralls.io/github/kollavarsham/kollavarsham-js?branch=master)

> Convert Gregorian date to Kollavarsham date and vice versa

## Install

### TypeScript/JavaScript/Node.js [![NPM version](https://badge.fury.io/js/kollavarsham.svg)](https://badge.fury.io/js/kollavarsham)

```sh
$ npm install kollavarsham
```

### Python [![PyPI version](https://badge.fury.io/py/kollavarsham.svg)](https://badge.fury.io/py/kollavarsham)

```sh
$ pip install kollavarsham
```

### C#/dotnet [![NuGet version](https://badge.fury.io/nu/KollavarshamOrg.Converter.svg)](https://badge.fury.io/nu/KollavarshamOrg.Converter)

```sh
$ dotnet add package KollavarshamOrg.Converter
```

## Usage

### TypeScript/JavaScript/Node.js

```js
import { Kollavarsham } from 'kollavarsham';

const options = {
  system: 'SuryaSiddhanta',
  latitude: 10,
  longitude: 76.2
};

const kollavarsham = new Kollavarsham(options);

const today = kollavarsham.fromGregorianDate(new Date());

console.log(today.year, today.mlMasaName, today.date, `(${today.mlNaksatraName})`);
```

### Python

```python
import datetime
import pytz
import kollavarsham

now = pytz.utc.localize(datetime.datetime.utcnow())
kv = kollavarsham.Kollavarsham(latitude=10, longitude=76.2, system="SuryaSiddhanta")

today = kv.from_gregorian_date(date=now)
print(today.year, today.ml_masa_name, today.date, '(' + today.naksatra.ml_malayalam + ')')
```

### C#/dotnet

```csharp
using System;
using KollavarshamOrg;

namespace Test
{
    class Program
    {
        static void Main(string[] args)
        {
            var settings = new Settings {
                Latitude = 10,
                Longitude = 76.2,
                System = "SuryaSiddhanta"
            };
            var kv = new Kollavarsham(settings);
            var today = kv.FromGregorianDate(DateTime.Now);
            Console.WriteLine($"{today.Year.ToString()} {today.MlMasaName} {today.Date.ToString()} ({today.MlNaksatraName})");
        }
    }
}
```

## Documentation

### TypeScript/JavaScript/Node.js

Check out the [Kollavarsham class](https://kollavarsham.org/kollavarsham-js/module-kollavarsham.Kollavarsham.html) within the API documentation as this is the entry point into the library.

## Release History

Check out the history at [GitHub Releases](https://github.com/kollavarsham/kollavarsham-js/releases)

## License

Copyright (c) 2014-2020 The Kollavarsham Team. Licensed under the [MIT license](http://kollavarsham.org/LICENSE.txt).
